// src/index.ts
import { createHighlighter } from "shiki";
import { transformerMetaWordHighlight } from "@shikijs/transformers";
import { JSDOM } from "jsdom";
import theme from "@jcayzac/shiki-theme-token";
import token from "@jcayzac/shiki-transformer-token";
import autolinks from "@jcayzac/shiki-transformer-autolinks";
var langs = /* @__PURE__ */ new Set([
  "ansi",
  "astro",
  "bash",
  "cpp",
  "css",
  "csv",
  "diff",
  "dockerfile",
  "dotenv",
  "git-commit",
  "git-rebase",
  "go",
  "html-derivative",
  "html",
  "http",
  "ini",
  "javascript",
  "jsonc",
  "jsx",
  "markdown",
  "python",
  "scss",
  "typescript",
  "yaml"
]);
var langAlias = {
  js: "javascript",
  json: "jsonc",
  md: "markdown",
  py: "python",
  sh: "bash",
  ts: "typescript"
};
var transformers = [
  transformerMetaWordHighlight(),
  token(),
  autolinks()
];
var highlighter = await createHighlighter({
  langs: [...langs],
  langAlias,
  themes: [theme]
});
function highlight(code, options = {}) {
  const lang = options.lang ?? "plaintext";
  if (!langs.has(lang) && !langAlias[lang]) {
    throw new Error(`Language "${lang}" is not supported. Supported languages are:
${[...langs].join(", ")}`);
  }
  const { meta, inline } = options;
  let metaProps = {};
  if (typeof meta === "string") {
    metaProps = {
      meta: {
        __raw: meta
      }
    };
  }
  const highlighted = highlighter.codeToHtml(code, {
    lang,
    ...metaProps,
    theme: "token",
    defaultColor: false,
    cssVariablePrefix: "--shiki-",
    transformers
  });
  const selector = inline ? "code > span" : "code";
  return JSDOM.fragment(highlighted).querySelector(selector)?.innerHTML;
}
var src_default = highlight;
export {
  src_default as default
};
//# sourceMappingURL=index.mjs.map